---
name: Bug Report
about: Create a report to help us improve rippled
title: "[Title with short description] (Version: [rippled version])"
labels: ''
assignees: ''

---
<!-- Please search existing issues to avoid creating duplicates.-->

## Issue Description
<!--Provide a summary for your issue/bug.-->

## Steps to Reproduce
<!--List in detail the exact steps to reproduce the unexpected behavior of the software.-->

## Expected Result
<!--Explain in detail what behavior you expected to happen.-->

## Actual Result
<!--Explain in detail what behavior actually happened.-->

## Environment
<!--Please describe your environment setup (such as Ubuntu 18.04 with Boost 1.70).-->
<!-- If you are using a formal release, please use the version returned by './rippled --version' as the version number-->
<!-- If you are working off of develop, please add the git hash via 'git rev-parse HEAD'-->

## Supporting Files
<!--If you have supporting files such as a log, feel free to post a link here using Github Gist.-->
<!--Consider adding configuration files with private information removed via Github Gist. -->

